@@ -1,8 +1,10 @@
 import collections
 import pathlib
+import operator
 
 from . import abc
 
+from ._itertools import unique_everseen
 from ._compat import ZipPath
 
 
@@ -65,13 +67,8 @@ class MultiplexedPath(abc.Traversable):
             raise NotADirectoryError('MultiplexedPath only supports directories')
 
     def iterdir(self):
-        visited = []
-        for path in self._paths:
-            for file in path.iterdir():
-                if file.name in visited:
-                    continue
-                visited.append(file.name)
-                yield file
+        files = (file for path in self._paths for file in path.iterdir())
+        return unique_everseen(files, key=operator.attrgetter('name'))
 
     def read_bytes(self):
         raise FileNotFoundError(f'{self} is not a file')
@@ -96,15 +93,16 @@ class MultiplexedPath(abc.Traversable):
     __truediv__ = joinpath
 
     def open(self, *args, **kwargs):
-        raise FileNotFoundError(f'{self} is not a file')
+        raise FileNotFoundError('{} is not a file'.format(self))
 
     @property
     def name(self):
         return self._paths[0].name
 
     def __repr__(self):
-        paths = ', '.join(f"'{path}'" for path in self._paths)
-        return f'MultiplexedPath({paths})'
+        return 'MultiplexedPath({})'.format(
+            ', '.join("'{}'".format(path) for path in self._paths)
+        )
 
 
 class NamespaceReader(abc.TraversableResources):
